@@ -43,6 +43,7 @@
 #include <QTableView>
 #include <QPrinter>
 #include <QAction>
+#include <QRandomGenerator>
 #include <QFileDialog>
 #include <QStatusBar>
 #include <QMenuBar>
@@ -99,7 +100,9 @@ class Add3DOption : public InlineOptions
         KAlgebra* m_kalgebra;
 };
 
-QColor randomFunctionColor() { return QColor::fromHsv(qrand()%255, 255, 255); }
+QColor randomFunctionColor() {
+    return QColor::fromHsv(QRandomGenerator::global()->bounded(255), 255, 255);
+}
 
 KAlgebra::KAlgebra(QWidget *parent)
     : QMainWindow(parent)
@@ -199,7 +202,7 @@ KAlgebra::KAlgebra(QWidget *parent)
     b_funcsModel=new Analitza::PlotsModel(this);
     
     m_graph2d = new Analitza::PlotsView2D(m_tabs);
-    m_graph2d->setTicksShown(0);
+    m_graph2d->setTicksShown(Qt::Orientation(0));
     m_graph2d->setModel(b_funcsModel);
     
     b_dock_funcs = new QDockWidget(i18n("Functions"), this);
@@ -395,7 +398,7 @@ void KAlgebra::initializeRecentScripts()
 
 void KAlgebra::newInstance()
 {
-    QProcess::startDetached(QApplication::applicationFilePath());
+    QProcess::startDetached(QApplication::applicationFilePath(), QStringList());
 }
 
 void KAlgebra::add2D(const Analitza::Expression& exp)
